InvoiceModel class

Constructors

InvoiceModel()

Properties

client ClientModel
getter/setter pair
contact ClientContact
getter/setter pair
date DateTime
getter/setter pair
entries List<InvoiceEntry>
getter/setter pair
fieldKeys Iterable<String>
Returns all the available field keys in this object.
no setterinherited
getterSetterMap Map<String, Tuple2<Getter, Setter>>
Used by toMap to generate the map
latefinalinherited
hashCode int
The hash code for this object.
no setterinherited
hasReceipt bool
getter/setter pair
id String?
getter/setter pairinherited
idKey String
Represents the field key used for the id
no setterinherited
invoiceId String?
getter/setter pair
lastUpdated DateTime
getter/setter pair
project String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
Unique type to give to the model. Whether or not collision is expected is dependent on the parameters of your system.
no setter
typeKey String
Represents the field key used for the type
no setterinherited

Methods

calculateTotal() double
Adds up the entries to get the full total
getField(String key) → dynamic
Returns the value of the field with name key or null if key is not a field in this model.
inherited
getGetterSetterMap() Map<String, Tuple2<Getter, Setter>>
Implemented by subclasses to map the getters and setters of the object.
loadFromMap(Map<String, dynamic> map, {bool respectType = true}) → void
Loads a Serializable map into the values of this BaseModel
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setField(String key, dynamic value) bool
Sets the field with name key to the given value
inherited
toMap() Map<String, dynamic>
Converts this BaseModel into a Serializable Map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited